# ncn (Nominal Composition Notation)

Use cnc to name, parse and find nominal composition notation.

## name

```python
from ncn import name

print(name(balance='Ti', hyphen=True, Al=6, V=4))
# Output: Ti-6Al-4V
```

## parse

```python
from ncn import parse

composition = parse('Ti-6Al-4V', balance=True)
print(composition)
# Output: {'Al': 6.0, 'V': 4.0, 'Ti': 90.0}
``` 

## find

```python
from ncn import find

results = find('Titanium Ti-8Al-1Mo-1V (Ti-8-1-1) Annealed 8 hr at 790°C (1450°F)')
print(results)
# Output: ['Ti-8Al-1Mo-1V']
```